@@ -215,6 +215,7 @@ protected:
   bool crc;              ///< CRC-32 appears at the end of each section.
   bool ignore_crc;       ///< Do not test the CRC value on expansion.
   bool reserved0;        ///< Not used.
+  bool quiet;            ///< Don't print compression statistics
 };
 
 
@@ -276,6 +277,7 @@ public:
   // Inline read-only access to private data.
   size_t get_raw_size() const {return raw_size;} ///< Read raw file size.
   size_t get_frame_size() const {return frame_size;} ///< Read raw frame size.
+  void   set_quiet(bool q) {quiet=q;} ///< Don't print compression statistics
 
 private: 
   // Private methods
@@ -308,6 +310,7 @@ private:
   size_t sec_bytes_stored;///< Bytes stored into current section.
   obitstream *ob;        ///< The bitstream for compressed output.
   bool encode_deltas;    ///< Should all channels encode deltas.
+  bool quiet;            ///< Don't print compression statistics
 };
 
 
@@ -332,6 +335,7 @@ public:
   size_t get_rawsize() const {return raw_size;} ///< Read slim file's raw size.
   size_t get_slimsize() const {return slim_size;} ///< Read slim file size.
   void   set_ignore_crc(bool ic=true) {ignore_crc=ic;} ///< Ignore CRCs
+  void   set_quiet(bool q) {quiet=q;} ///< Don't print compression statistics
 
 
 private:
@@ -366,6 +370,7 @@ private:
   slim_channel_array channels;///< Array of all channels in this data file.
   unsigned int num_frames;///< Number of frames in the current section.
   ibitstream *ib;        ///< The bitstream for compressed input
+  bool quiet;            ///< Don't print compression statistics
 };
 
 
