@@ -35,7 +35,7 @@
 
 
 /// Single-character options
-const char short_opt[] = "m:c:r:F:dnpXxSC0bPokuivsfg987654321V?B:";
+const char short_opt[] = "m:c:r:F:dnpXxSC0bPokquivsfg987654321V?B:";
 
 /// The long options slim recognizes.
 const static struct option long_opt[] = {
@@ -55,6 +55,7 @@ const static struct option long_opt[] = {
   {"practice",          no_argument,       NULL, 'P'},
   {"stdout",            no_argument,       NULL, 'o'},
   {"force",             no_argument,       NULL, 'k'},
+  {"quiet",             no_argument,       NULL, 'q'},
   {"unsigned",          no_argument,       NULL, 'u'},
   {"int",               no_argument,       NULL, 'i'},
   {"ushort",            no_argument,       NULL, 'v'},
@@ -204,6 +205,10 @@ void slim_control::process_args(int argc, char * const argv[])
       force_clobber = true;
       break;
 
+    case 'q':
+      quiet = true;
+      break;
+
     case 'u':
       data_type = SLIM_TYPE_U32;
       break;
@@ -348,6 +353,7 @@ void slim_control::set_defaults()
   ignore_crc = false;
   reserved0 = false;
   practice = false;
+  quiet = false;
 }
 
 
@@ -512,6 +518,7 @@ void slim_control::compress_one_file(const char *rawname) {
 		    deltas, permit_bitrotation);
 
   compressor->set_section_frames(nframes_thisfile);
+  compressor->set_quiet(quiet);
   compressor->compress_from_file(rawname);
   delete compressor;
 
@@ -521,8 +528,9 @@ void slim_control::compress_one_file(const char *rawname) {
   int ret2 = stat(outname, &st_out);
   if (ret1 || ret2) return;
   if (!force_clobber && (st_raw.st_size <= st_out.st_size)) {
-    cerr << "slim: " << rawname << 
-      " expanded when slimmed (use -k to force).\n";
+    if (!quiet)
+      cerr << "slim: " << rawname << 
+        " expanded when slimmed (use -k to force).\n";
     unlink(outname);
   } else if (practice) {
     unlink(outname);
@@ -548,6 +556,16 @@ void slim_control::expand_one_file(const char *compname) {
   // But if we have --preserve, then append a ".raw" suffix instead.
   const char *last_suffix = strrchr(compname,'.');
   size_t baselen;
+#ifdef HAVE_LIBLZ4
+  if (last_suffix &&
+    (!strcmp(last_suffix, ".lz4") || !strcmp(last_suffix, ".LZ4"))) {
+    // Strip off extra LZ4 suffix if found
+    char *period = (char*) last_suffix;
+    ((char *) last_suffix)[0] = '\0';
+    last_suffix = strrchr(compname, '.');
+    period[0] = '.';
+  }
+#endif
   if (last_suffix)
     baselen = (last_suffix-compname);
   else
@@ -580,6 +598,7 @@ void slim_control::expand_one_file(const char *compname) {
   slim_expander_t *expander = new slim_expander_t(compname);
   if (ignore_crc)
     expander->set_ignore_crc();
+  expander->set_quiet(quiet);
 
   if (use_stdout)
     expander->expand_to_stdout();
@@ -703,6 +722,12 @@ void slim_control::debug_expand_from_memory(const char *compname) {
     expander->set_ignore_crc();
 
   FILE *fp = fopen(rawname, "wb");
+  if (fp == NULL) {
+    cerr << "slim: " << rawname << ": Unable to open file for writing\n";
+    delete [] rawname;
+    delete expander;
+    return;
+  }
   unsigned char *buf = new unsigned char[debug_buf_size];
 
   size_t written=0, read=0;
